Module blaxel.models.revision_metadata
======================================

Classes
-------

`RevisionMetadata(active: blaxel.types.Unset | bool = <blaxel.types.Unset object>, canary: blaxel.types.Unset | bool = <blaxel.types.Unset object>, created_at: blaxel.types.Unset | str = <blaxel.types.Unset object>, created_by: blaxel.types.Unset | str = <blaxel.types.Unset object>, id: blaxel.types.Unset | str = <blaxel.types.Unset object>, previous_active: blaxel.types.Unset | bool = <blaxel.types.Unset object>, status: blaxel.types.Unset | str = <blaxel.types.Unset object>, traffic_percent: blaxel.types.Unset | int = <blaxel.types.Unset object>)`
:   Revision metadata
    
    Attributes:
        active (Union[Unset, bool]): Is the revision active
        canary (Union[Unset, bool]): Is the revision canary
        created_at (Union[Unset, str]): Revision created at
        created_by (Union[Unset, str]): Revision created by
        id (Union[Unset, str]): Revision ID
        previous_active (Union[Unset, bool]): Is the revision previous active
        status (Union[Unset, str]): Status of the revision
        traffic_percent (Union[Unset, int]): Percent of traffic to the revision
    
    Method generated by attrs for class RevisionMetadata.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `active: blaxel.types.Unset | bool`
    :

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `canary: blaxel.types.Unset | bool`
    :

    `created_at: blaxel.types.Unset | str`
    :

    `created_by: blaxel.types.Unset | str`
    :

    `id: blaxel.types.Unset | str`
    :

    `previous_active: blaxel.types.Unset | bool`
    :

    `status: blaxel.types.Unset | str`
    :

    `traffic_percent: blaxel.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :